@@ -3,17 +3,16 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.0901';
+our $VERSION = '0.0902';
 
 use Carp;
-
+use List::MoreUtils 'first_index';
 use Moo;
+use Music::Scales;
+
 use strictures 2;
 use namespace::clean;
 
-use List::MoreUtils 'first_index';
-use Music::Scales;
-
 
 has scale_note => (
     is      => 'ro',
@@ -68,7 +67,7 @@ sub parse {
 
     # Get the roman representation based on the scale position
     my $position = first_index { $_ eq $note } @notes;
-    # If the note is note in the scale find a new position and accidental
+    # If the note is not in the scale find a new position and accidental
     my $accidental;
     if ( $position == -1 ) {
         ( $position, $accidental ) = _pos_acc( $note, $position, \@notes );
@@ -155,7 +154,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0901
+version 0.0902
 
 =head1 SYNOPSIS
 
@@ -165,6 +164,7 @@ version 0.0901
     scale_note => 'A',
     scale_name => 'minor',
   );
+
   my $roman = $mtr->parse('Am');  # i (minor)
   $roman = $mtr->parse('Bo');     # iio (diminished)
   $roman = $mtr->parse('Bdim');   # iio (diminished)
@@ -180,12 +180,12 @@ version 0.0901
   $roman = $mtr->parse('Fmin7');  # vi min7 (minor seventh)
   $roman = $mtr->parse('G+');     # VII+ (augmented)
 
-  # Also:
   $mtr = Music::ToRoman->new(
     scale_note => 'A',
     scale_name => 'dorian',
     chords     => 0,
   );
+
   $roman = $mtr->parse('A');      # i
   $roman = $mtr->parse('B');      # ii
   $roman = $mtr->parse('C');      # III
@@ -201,11 +201,9 @@ version 0.0901
 
 =head1 DESCRIPTION
 
-C<Music::ToRoman> converts chords to Roman numeral notation.  Also individual
-"chordless" notes may be converted given a diatonic mode B<scale_name>.
-
-For example usage, check out the files F<eg/roman> and F<eg/basslines> in
-L<Music::BachChoralHarmony>.
+C<Music::ToRoman> converts named chords to Roman numeral notation.
+Also individual "chordless" notes may be converted given a diatonic
+mode B<scale_name>.
 
 =head1 ATTRIBUTES
 
@@ -213,7 +211,7 @@ L<Music::BachChoralHarmony>.
 
 Note on which the scale is based.
 
-Default: C
+Default: C<C>
 
 =head2 scale_name
 
@@ -227,26 +225,30 @@ Name of the scale.  The diatonic mode names supported are:
   aeolian / minor
   locrian
 
-Default: major
+Default: C<major>
 
 =head2 chords
 
-Are we given chords to B<parse> with major (C<M>) and minor (C<m>) designations?
+Are we given chords to B<parse> with major (C<M>) and minor (C<m>)
+designations?
 
-Default: 1
+Default: C<1>
 
-If this is set to 0, single notes can be used to return the major/minor Roman
-numeral for the given diatonic mode B<scale_name>.
+If this is set to C<0>, single notes can be used to return the
+major/minor Roman numeral for the given diatonic mode B<scale_name>.
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
-  $mtr = Music::ToRoman->new(%arguments);
+  $mtr = Music::ToRoman->new(
+    scale_note => $note,
+    scale_name => $name,
+  );
 
 Create a new C<Music::ToRoman> object.
 
-=head2 parse()
+=head2 parse
 
   $roman = $mtr->parse($chord);
 
@@ -268,14 +270,17 @@ A diminished chord may be given as C<dim>, which is then converted to C<o>.
 
 =head1 SEE ALSO
 
-L<Moo>
-
 L<List::MoreUtils>
 
+L<Moo>
+
 L<Music::Scales>
 
 L<https://en.wikipedia.org/wiki/Roman_numeral_analysis>
 
+For example usage, check out the files F<eg/roman> and F<eg/basslines> in
+L<Music::BachChoralHarmony>.
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
